package com.bipt.intelligentapplicationorchestrationservice.controller;

import com.bipt.intelligentapplicationorchestrationservice.pojo.*;
import com.bipt.intelligentapplicationorchestrationservice.service.ModelService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

@Slf4j
@RestController
@RequestMapping("/model")
@Tag(name = "模型部分相关接口")
@CrossOrigin(origins = "http://localhost:3000")   // 生产环境指定具体域名
public class ModelController {
    @Autowired
    private ModelService modelService;
    @Operation(summary = "创建模型")
    @PostMapping("/createModel")
    public OptResult creatModel(@RequestBody ModelDTO dto){
        log.info("创建模型");
        modelService.createModel(dto);
        return OptResult.success();
    }

    @Operation(summary = "新增模型版本")
    @PostMapping("/createModelVersion")
    public OptResult createModelVersion(@RequestBody ModelDTO dto){
        log.info("新增模型版本");
        modelService.createModelVersion(dto);
        return OptResult.success();
    }

    @Operation(summary = "查询模型列表")
    @GetMapping("list")
    public OptResult list(){
        log.info("查询模型列表");
        List<ModelVO> modelVOList = modelService.list();
        return OptResult.success(modelVOList);
    }

    @Operation(summary = "查询模型详情")
    @GetMapping("detail")
    public OptResult detail(Long id){
        log.info("查询模型详情");
        ModelVersion  modelVersion = modelService.detail(id);
        return OptResult.success(modelVersion);
    }

    @Operation(summary = "模型更新")
    @PutMapping("/updateModel")
    public OptResult updateModel(@RequestBody ModelVersionDTO dto){
        log.info("模型更新");
        modelService.updateModel(dto);
        return OptResult.success();
    }


    @Operation(summary = "模型版本删除")
    @DeleteMapping("/deleteModelVersion")
    public OptResult deleteModelVersion(Long id){
        log.info("模型版本删除");
        modelService.deleteModelVersion(id);
        return OptResult.success();
    }

    @Operation(summary = "更新生命周期")
    @PutMapping("/updateLifeCycle")
    public OptResult updateLifeCycle(Long id,String lifeCycle){
        log.info("更新生命周期");
        modelService.updateLifeCycle(id,lifeCycle);
        return OptResult.success();
    }

    @Operation(summary = "查询生命周期列表")
    @GetMapping("/listLifeCycle")
    public OptResult listLifeCycle(){
        log.info("查询生命周期列表");
        List<Map<String, String>> lifeCycleList = modelService.listLifeCycle();
        return OptResult.success(lifeCycleList);
    }

    @Operation(summary = "查询数据集列表")
    @GetMapping("/listDataset")
    public OptResult listDataset(){
        List<DatasetEntity> datasetList = modelService.listDataset();
        return OptResult.success(datasetList);
    }


}
