package com.bipt.intelligentapplicationorchestrationservice.service.Impl;

import com.bipt.intelligentapplicationorchestrationservice.mapper.AlgorithmInfoMapper;
import com.bipt.intelligentapplicationorchestrationservice.pojo.AlgorithmInfo;
import com.bipt.intelligentapplicationorchestrationservice.service.AlgorithmInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.StringUtils;

import java.util.List;

@Service
public class AlgorithmInfoServiceImpl implements AlgorithmInfoService {

    @Autowired
    private AlgorithmInfoMapper algorithmInfoMapper;

    @Override
    public AlgorithmInfo getById(Long id) {
        return algorithmInfoMapper.selectById(id);
    }

    @Override
    public AlgorithmInfo getByName(String algorithmName) {
        return algorithmInfoMapper.selectByName(algorithmName);
    }

    @Override
    public List<AlgorithmInfo> getByType(String algorithmType) {
        return algorithmInfoMapper.selectByType(algorithmType);
    }

    @Override
    @Transactional
    public boolean update(AlgorithmInfo algorithmInfo) {
        if (!validateAlgorithmInfo(algorithmInfo)) {
            return false;
        }
        return algorithmInfoMapper.update(algorithmInfo) > 0;
    }

    @Override
    @Transactional
    public boolean delete(Long id) {
        return algorithmInfoMapper.deleteById(id) > 0;
    }

    @Override
    public boolean validateAlgorithmInfo(AlgorithmInfo algorithmInfo) {
        if (algorithmInfo == null) {
            return false;
        }
        
        if (!StringUtils.hasText(algorithmInfo.getAlgorithmName()) ||
            !StringUtils.hasText(algorithmInfo.getAlgorithmFile()) ||
            !StringUtils.hasText(algorithmInfo.getAlgorithmType())) {
            return false;
        }
        
        return true;
    }

    /**
     * 算法创建
     * @param algorithmInfo
     */
    @Override
    @Transactional
    public void save(AlgorithmInfo algorithmInfo) {
        String algorithmName = algorithmInfo.getAlgorithmName();
        //查找表里是否有重复的算法，如果有则报错
        AlgorithmInfo duplicateName = algorithmInfoMapper.selectByName(algorithmName);
        if (duplicateName != null){
            throw new RuntimeException("算法已存在");
        }
        //todo 算法文件分布式存入分布式存储中


        algorithmInfoMapper.insert(algorithmInfo);
    }
} 